#!/bin/bash


##### STEP 1 - (see tuto2.xcm)
#############################






##### STEP 2 - Create mock event lists and spectra with HEAsim (and Xselect)
############################################################################



### 2.1 Initialize heasim

source heasim.sh

# Before sourcing heasim.sh, make sure to edit it and write the location of your tuto2/ folder!

# For this tutorial, I'll be using my own initialization file which I put in my home directory: 
# source ~/heasim.sh



### 2.2 Run heasim for the baseline case of the Perseus cluster (1 ICM component + 1 AGN component, having ech their own spectral model)

heasim mission=hitomi instrume=sxs rapoint=49.95 decpoint=41.51 roll=0.00 exposure=350000. insrcdeffile=perseus_betaicm_brptsrc.dat outfile=perseus_betaicm_brptsrc.fits psffile=$HEASIM_SUPPORT/xrism/resolve/psf/eef_from_sxs_psfimage_20140618.fits vigfile=$HEASIM_SUPPORT/xrism/resolve/vignette/SXT_VIG_140618.txt rmffile=$HEASIM_SUPPORT/xrism/resolve/response/resolve_h5ev_2019a.rmf arffile=$HEASIM_SUPPORT/xrism/resolve/response/resolve_pnt_heasim_withGV_20190701.arf intbackfile=$HEASIM_SUPPORT/xrism/resolve/background/resolve_h5ev_2019a_rslnxb.pha flagsubex=no seed=1234567890 clobber=yes



### 2.3 Now that we have our mock event list (perseus_betaicm_brptsrc.fits), let's extract a spectrum out of it! You can either type "xselect" and enter the following commands or – if you want a more automated script, – edit the EOF header line with your own path of Xselect (you can access it by typing "which xselect")


/Users/fmernier/APPS/heasoft-6.34/aarch64-apple-darwin24.1.0/bin/xselect << EOF
set mission hitomi
set instrument SXS
read events perseus_betaicm_brptsrc.fits
./
extract spectrum
save spectrum perseus_betaicm_brptsrc.pi
exit
y
EOF




##### STEP 2 (Alternative case) - Using an image for the sdf
############################################################


heasim mission=hitomi instrume=sxs rapoint=49.95 decpoint=41.51 roll=0.00 exposure=350000. insrcdeffile=perseus_imageicm.dat outfile=perseus_imageicm.fits psffile=$HEASIM_SUPPORT/xrism/resolve/psf/eef_from_sxs_psfimage_20140618.fits vigfile=$HEASIM_SUPPORT/xrism/resolve/vignette/SXT_VIG_140618.txt rmffile=$HEASIM_SUPPORT/xrism/resolve/response/resolve_h5ev_2019a.rmf arffile=$HEASIM_SUPPORT/xrism/resolve/response/resolve_pnt_heasim_withGV_20190701.arf intbackfile=$HEASIM_SUPPORT/xrism/resolve/background/resolve_h5ev_2019a_rslnxb.pha flagsubex=no seed=1234567890 clobber=yes


/Users/fmernier/APPS/heasoft-6.34/aarch64-apple-darwin24.1.0/bin/xselect << EOF
set mission hitomi
set instrument SXS
read events perseus_imageicm.fits
./
extract image
save image perseus_imageicm.img
exit
y
EOF




### Alternative: extra DM line

heasim mission=hitomi instrume=sxs rapoint=49.95 decpoint=41.51 roll=0.00 exposure=350000. insrcdeffile=perseus_betaicm_brptsrc_line.dat outfile=perseus_betaicm_brptsrc_line.fits psffile=$HEASIM_SUPPORT/xrism/resolve/psf/eef_from_sxs_psfimage_20140618.fits vigfile=$HEASIM_SUPPORT/xrism/resolve/vignette/SXT_VIG_140618.txt rmffile=$HEASIM_SUPPORT/xrism/resolve/response/resolve_h5ev_2019a.rmf arffile=$HEASIM_SUPPORT/xrism/resolve/response/resolve_pnt_heasim_withGV_20190701.arf intbackfile=$HEASIM_SUPPORT/xrism/resolve/background/resolve_h5ev_2019a_rslnxb.pha flagsubex=no seed=1234567890 clobber=yes

/Users/fmernier/APPS/heasoft-6.34/aarch64-apple-darwin24.1.0/bin/xselect << EOF
set mission hitomi
set instrument SXS
read events perseus_betaicm_brptsrc_line.fits
./
extract spectrum
save spectrum perseus_betaicm_brptsrc_line.pi
exit
EOF


##### STEP 3 - Fit spectra with Xspec (see tuto2.xcm)
#####################################################




##### STEP 4 - Calculate branching ratio
########################################

sxsbranch infile=perseus_betaicm_brptsrc.fits filetype=sim outfile=perseus_betaicm_brptsrc_branch.out pixfrac=$HEASIM_SUPPORT/xrism/resolve/sxsbranch/pixfrac.txt pixmask=none ctelpixfile=$HEASIM_SUPPORT/xrism/resolve/sxsbranch/pixmap.fits ctphafrac1=0.0 ctphafrac2=0.0

sxsbranch infile=perseus_betaicm_brptsrc.fits filetype=sim outfile=perseus_betaicm_brptsrc_branch.out pixfrac=$HEASIM_SUPPORT/xrism/resolve/sxsbranch/pixfrac.txt pixmask=none ctelpixfile=$HEASIM_SUPPORT/xrism/resolve/sxsbranch/pixmap.fits ctphafrac1=0.0 ctphafrac2=0.0 dtprimary=70.72 dtmidhigh=70.72 dtlowmid=18.32



